==> helpdesk.selectransportation.com_BCK%2001.12.2026.zip: helpdesk.selectransportation.com/Undercontruction.php <==
<?php

/* =========================================================
-- Author: Saquib Patwa
-- Create date: 06/25/2019
-- Last Modified on: 10/31/19
-- Description: RSVP Page for the Annual Holiday Party.
-- =========================================================== */

//For enabling and disabling the helpdesk page
include 'ToggleHelpdeskConfig.php';

// Check if helpdesk is enabled; if so, redirect to the main helpdesk page
if ($HelpdeskEnabled) {
    header('Location: index.php'); // Or rsvp.php
    exit();
}


?>


<!DOCTYPE html>
<html lang="en">
 <head>
   <!-- Required meta tags -->
   <meta charset="utf-8">
   <meta http-equiv="X-UA-Compatible" content="IE=Edge,chrome=1" />
   <meta name="viewport" content="width=device-width, initial-scale=1">
   <meta http-equiv="cache-control" content="no-cache">

          <title>STR Help Desk</title>

          <!--===============================================================================================-->
              <!-- Favicon -->
              <!-- <link rel="icon" type="image/png" href="../helpdesk/Images/icons/help.ico"/> -->
          <!--===============================================================================================-->
              <!-- Bootstrap CSS -->
              <link rel="stylesheet" type="text/css" href="/vendor/bootstrap/css/bootstrap.min.css">
              <link href="/css/bootstrap_v3.2.0.css" rel="stylesheet" type="text/css" />
          <!--===============================================================================================-->
              <!-- Font Awesome -->
              <!-- <link rel="stylesheet" type="text/css" href="/helpdesk/fonts/font-awesome-4.7.0/css/font-awesome.min.css"> -->
              <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">


          <!--===============================================================================================-->
              <!-- Fonts -->
              <!-- <link rel="stylesheet" type="text/css" href="/css/util.css"> -->
              <!-- Main CSS -->
              <link rel="stylesheet" type="text/css" href="/css/main.css">
              <!-- forms and Buttons -->
              <!-- <link rel="stylesheet" type="text/css" href="/css/misc.css"> -->
          <!--===============================================================================================-->

          <!--===============================================================================================-->
           <!-- This is to create an App Icon when you save to you website to your homescreen.
                Use the website www.favicon-generator.org/ to create an app icon and the code from the same website -->

               <link rel="apple-touch-icon" sizes="57x57" href="../Images/icons/Icons/apple-icon-57x57.png">
               <link rel="apple-touch-icon" sizes="60x60" href="../Images/icons/Icons/apple-icon-60x60.png">
               <link rel="apple-touch-icon" sizes="72x72" href="../Images/icons/Icons/apple-icon-72x72.png">
               <link rel="apple-touch-icon" sizes="76x76" href="../Images/icons/Icons/apple-icon-76x76.png">
               <link rel="apple-touch-icon" sizes="114x114" href="../Images/icons/Icons/apple-icon-114x114.png">
               <link rel="apple-touch-icon" sizes="120x120" href="../Images/icons/Icons/apple-icon-120x120.png">
               <link rel="apple-touch-icon" sizes="144x144" href="../Images/icons/Icons/apple-icon-144x144.png">
               <link rel="apple-touch-icon" sizes="152x152" href="../Images/icons/Icons/apple-icon-152x152.png">
               <link rel="apple-touch-icon" sizes="180x180" href="../Images/icons/Icons/apple-icon-180x180.png">
               <link rel="icon" type="image/png" sizes="192x192"  href="../Images/icons/Icons/android-icon-192x192.png">
               <link rel="icon" type="image/png" sizes="32x32" href="../Images/icons/Icons/favicon-32x32.png">
               <link rel="icon" type="image/png" sizes="96x96" href="../Images/icons/Icons/favicon-96x96.png">
               <link rel="icon" type="image/png" sizes="16x16" href="../Images/icons/Icons/favicon-16x16.png">
               <link rel="mask-icon" href="../Images/icons/Icons/safari-pinned-tab.svg" color="#5bbad5">
               <link rel="manifest" href="../Images/icons/Icons/manifest.json">
               <meta name="msapplication-TileColor" content="#ffffff">
               <meta name="msapplication-TileImage" content="../Images/icons/Icons/ms-icon-144x144.png">
               <meta name="theme-color" content="#ffffff">

           <!--===============================================================================================-->

<head>
  <style>

  .bg{
    /* background: url('/helpdesk/Images/BGForm.jpg'); */
    /* background-position: top center;
    background-repeat: no-repeat;
    background-size: cover;
    background-attachment: fixed;
   -webkit-background-size: cover;
     -moz-background-size: cover;
     -o-background-size: cover;
     width:100%;
     height: 100%;
     overflow: auto; */

     /* background: url("/helpdesk/Images/FrhtBG.png"); */
     background-color: #eee;
     display: flex;
     margin: 0 auto;
     padding: 0;
     justify-content: center;
     align-items: center;
     height: 100vh;
     background-position: top center;
     background-repeat: no-repeat;
     background-size: cover;
     -webkit-background-size: cover;
     -moz-background-size: cover;
     -o-background-size: cover;
     background-attachment: fixed;
     width:100%;
      /* height: 100%; */
      overflow: auto;

  }

  </style>
</head>
<body class="bg">

  <div  align="center" style="color:white; text-shadow: 2px 2px 4px #000; width: 100%">
    <img src = "/Images/Logo-Main.png"   /><br /><br />
       <img src = "/Images/maintenance.png"   />
       <h1>Apologies, we are doing some work on the site.  We will be back shortly. <br /> We will appreciate your patience. </h1>
     </div>

</body>

</html>

==> helpdesk.selectransportation.com_BCK%2010.14.2025.zip: helpdesk.selectransportation.com/Undercontruction.php <==
<?php

/* =========================================================
-- Author: Saquib Patwa
-- Create date: 06/25/2019
-- Last Modified on: 10/31/19
-- Description: RSVP Page for the Annual Holiday Party.
-- =========================================================== */

//For enabling and disabling the helpdesk page
include 'ToggleHelpdeskConfig.php';

// Check if helpdesk is enabled; if so, redirect to the main helpdesk page
if ($HelpdeskEnabled) {
    header('Location: index.php'); // Or rsvp.php
    exit();
}


?>


<!DOCTYPE html>
<html lang="en">
 <head>
   <!-- Required meta tags -->
   <meta charset="utf-8">
   <meta http-equiv="X-UA-Compatible" content="IE=Edge,chrome=1" />
   <meta name="viewport" content="width=device-width, initial-scale=1">
   <meta http-equiv="cache-control" content="no-cache">

          <title>STR Help Desk</title>

          <!--===============================================================================================-->
              <!-- Favicon -->
              <!-- <link rel="icon" type="image/png" href="../helpdesk/Images/icons/help.ico"/> -->
          <!--===============================================================================================-->
              <!-- Bootstrap CSS -->
              <link rel="stylesheet" type="text/css" href="/vendor/bootstrap/css/bootstrap.min.css">
              <link href="/css/bootstrap_v3.2.0.css" rel="stylesheet" type="text/css" />
          <!--===============================================================================================-->
              <!-- Font Awesome -->
              <!-- <link rel="stylesheet" type="text/css" href="/helpdesk/fonts/font-awesome-4.7.0/css/font-awesome.min.css"> -->
              <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">


          <!--===============================================================================================-->
              <!-- Fonts -->
              <!-- <link rel="stylesheet" type="text/css" href="/css/util.css"> -->
              <!-- Main CSS -->
              <link rel="stylesheet" type="text/css" href="/css/main.css">
              <!-- forms and Buttons -->
              <!-- <link rel="stylesheet" type="text/css" href="/css/misc.css"> -->
          <!--===============================================================================================-->

          <!--===============================================================================================-->
           <!-- This is to create an App Icon when you save to you website to your homescreen.
                Use the website www.favicon-generator.org/ to create an app icon and the code from the same website -->

               <link rel="apple-touch-icon" sizes="57x57" href="../Images/icons/Icons/apple-icon-57x57.png">
               <link rel="apple-touch-icon" sizes="60x60" href="../Images/icons/Icons/apple-icon-60x60.png">
               <link rel="apple-touch-icon" sizes="72x72" href="../Images/icons/Icons/apple-icon-72x72.png">
               <link rel="apple-touch-icon" sizes="76x76" href="../Images/icons/Icons/apple-icon-76x76.png">
               <link rel="apple-touch-icon" sizes="114x114" href="../Images/icons/Icons/apple-icon-114x114.png">
               <link rel="apple-touch-icon" sizes="120x120" href="../Images/icons/Icons/apple-icon-120x120.png">
               <link rel="apple-touch-icon" sizes="144x144" href="../Images/icons/Icons/apple-icon-144x144.png">
               <link rel="apple-touch-icon" sizes="152x152" href="../Images/icons/Icons/apple-icon-152x152.png">
               <link rel="apple-touch-icon" sizes="180x180" href="../Images/icons/Icons/apple-icon-180x180.png">
               <link rel="icon" type="image/png" sizes="192x192"  href="../Images/icons/Icons/android-icon-192x192.png">
               <link rel="icon" type="image/png" sizes="32x32" href="../Images/icons/Icons/favicon-32x32.png">
               <link rel="icon" type="image/png" sizes="96x96" href="../Images/icons/Icons/favicon-96x96.png">
               <link rel="icon" type="image/png" sizes="16x16" href="../Images/icons/Icons/favicon-16x16.png">
               <link rel="mask-icon" href="../Images/icons/Icons/safari-pinned-tab.svg" color="#5bbad5">
               <link rel="manifest" href="../Images/icons/Icons/manifest.json">
               <meta name="msapplication-TileColor" content="#ffffff">
               <meta name="msapplication-TileImage" content="../Images/icons/Icons/ms-icon-144x144.png">
               <meta name="theme-color" content="#ffffff">

           <!--===============================================================================================-->

<head>
  <style>

  .bg{
    background: url('/helpdesk/Images/BGForm.jpg');
    /* background-position: top center;
    background-repeat: no-repeat;
    background-size: cover;
    background-attachment: fixed;
   -webkit-background-size: cover;
     -moz-background-size: cover;
     -o-background-size: cover;
     width:100%;
     height: 100%;
     overflow: auto; */

     /* background: url("/helpdesk/Images/FrhtBG.png"); */
     display: flex;
     margin: 0 auto;
     padding: 0;
     justify-content: center;
     align-items: center;
     height: 100vh;
     background-position: top center;
     background-repeat: no-repeat;
     background-size: cover;
     -webkit-background-size: cover;
     -moz-background-size: cover;
     -o-background-size: cover;
     background-attachment: fixed;
     width:100%;
      /* height: 100%; */
      overflow: auto;

  }

  </style>
</head>
<body class="bg">
  <div  align="center" style="color:white; text-shadow: 2px 2px 4px #000;">
       <h1>Apologies, we are doing some work on the site.  We will be back shortly. <br /> We will appreciate your patience. </h1>
     </div>

</body>

</html>
